@@ -67,6 +67,14 @@ setGeneric("intergenic<-", signature="x",
     function(x, value) standardGeneric("intergenic<-")
 )
 
+setGeneric("idType", signature="x",
+    function(x) standardGeneric("idType")
+)
+
+setGeneric("idType<-", signature="x",
+    function(x, value) standardGeneric("idType<-")
+)
+
 ### -------------------------------------------------------------------------
 ### read/write Vcf 
 ###
