@@ -3,7 +3,7 @@
 ###################################################
 ### code chunk number 1: style-Sweave
 ###################################################
-BiocStyle::latex()
+BiocStyle::latex2()
 
 
 ###################################################
@@ -65,7 +65,7 @@ filterVcf(tabix.file,  "hg19", destination.file,
 library(AnnotationHub)
 hub <- AnnotationHub()
 id <- names(query(hub, "wgEncodeUwTfbsMcf7CtcfStdPkRep1.narrowPeak"))
-mcf7.gr <- hub[[id]]
+mcf7.gr <- hub[[tail(id, 1)]]
 
 
 ###################################################
