@@ -76,7 +76,7 @@ test_VCF_rowRanges_info_geno <- function() {
     vcf <- readVcf(fl, genome="hg19")
     ## rowRanges
     v1 <- vcf
-    rowRanges(v1) <- rowRanges(v1)[5:1]
+    rowRanges(v1) <- rowRanges(v1, fixed=FALSE)[5:1]
     checkIdentical(rownames(vcf), rev(rownames(v1)))
 
     ## info
@@ -197,7 +197,7 @@ test_VCF_seqlevels <- function()
     seqlevels(vcf)[seqlevels(vcf) == "1"] <- "chr1"
     checkIdentical(seqlevels(vcf), c("chr1", "2", "3", "4"))
  
-    seqlevels(vcf, force=TRUE) <- "3"
+    seqlevels(vcf, pruning.mode="coarse") <- "3"
     checkIdentical(seqlevels(vcf), "3")
 }
 
